@@ -20,6 +20,7 @@ Archive Push Command
 #include "config/exec.h"
 #include "info/infoArchive.h"
 #include "postgres/interface.h"
+#include "postgres/version.h"
 #include "protocol/helper.h"
 #include "protocol/parallel.h"
 #include "storage/helper.h"
@@ -186,68 +187,81 @@ Check that pg_control and archive.info match and get the archive id and archive
 As much information as possible is collected here so that async archiving has as little work as possible to do for each file.  Sync
 archiving does not benefit but it makes sense to use the same function.
 ***********************************************************************************************************************************/
-#define FUNCTION_LOG_ARCHIVE_PUSH_CHECK_RESULT_TYPE                                                                                \
-    ArchivePushCheckResult
-#define FUNCTION_LOG_ARCHIVE_PUSH_CHECK_RESULT_FORMAT(value, buffer, bufferSize)                                                   \
-    objToLog(&value, "ArchivePushCheckResult", buffer, bufferSize)
-
 typedef struct ArchivePushCheckResult
 {
     unsigned int pgVersion;                                         // PostgreSQL version
     uint64_t pgSystemId;                                            // PostgreSQL system id
-    String *archiveId;                                              // Archive id for current pg version
-    String *archiveCipherPass;                                      // Archive cipher passphrase
+    ArchivePushFileRepoData *repoData;                              // Data for each repo
 } ArchivePushCheckResult;
 
 static ArchivePushCheckResult
-archivePushCheck(bool pgPathSet, CipherType cipherType, const String *cipherPass)
+archivePushCheck(bool pgPathSet)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(BOOL, pgPathSet);
-        FUNCTION_LOG_PARAM(ENUM, cipherType);
-        FUNCTION_TEST_PARAM(STRING, cipherPass);
     FUNCTION_LOG_END();
 
-    ArchivePushCheckResult result = {0};
+    ArchivePushCheckResult result = {.repoData = memNew(cfgOptionGroupIdxTotal(cfgOptGrpRepo) * sizeof(ArchivePushFileRepoData))};
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Attempt to load the archive info file
-        InfoArchive *info = infoArchiveLoadFile(storageRepo(), INFO_ARCHIVE_PATH_FILE_STR, cipherType, cipherPass);
-
-        // Get archive id for the most recent version -- archive-push will only operate against the most recent version
-        String *archiveId = infoPgArchiveId(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
-        InfoPgData archiveInfo = infoPgData(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
-
-        // Ensure that stanza version and system identifier match pg_control when available
+        // If we have access to pg_control then load it to get the pg version and system id. If we can't load pg_control then we'll
+        // still compare the pg info stored in the repo to the WAL segment and also all the repos against each other.
         if (pgPathSet)
         {
             // Get info from pg_control
-            PgControl controlInfo = pgControlFromFile(storagePg());
-
-            if (controlInfo.version != archiveInfo.version || controlInfo.systemId != archiveInfo.systemId)
-            {
-                THROW_FMT(
-                    ArchiveMismatchError,
-                    "PostgreSQL version %s, system-id %" PRIu64 " do not match stanza version %s, system-id %" PRIu64
-                    "\nHINT: are you archiving to the correct stanza?",
-                    strZ(pgVersionToStr(controlInfo.version)), controlInfo.systemId, strZ(pgVersionToStr(archiveInfo.version)),
-                    archiveInfo.systemId);
-            }
+            PgControl pgControl = pgControlFromFile(storagePg());
+            result.pgVersion = pgControl.version;
+            result.pgSystemId = pgControl.systemId;
         }
 
-        MEM_CONTEXT_PRIOR_BEGIN()
+        for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
         {
-            result.pgVersion = archiveInfo.version;
-            result.pgSystemId = archiveInfo.systemId;
-            result.archiveId = strDup(archiveId);
-            result.archiveCipherPass = strDup(infoArchiveCipherPass(info));
+            // Get the repo storage in case it is remote and encryption settings need to be pulled down
+            storageRepoIdx(repoIdx);
+
+            // Set cipher type in repo data
+            result.repoData[repoIdx].cipherType = cipherType(cfgOptionIdxStr(cfgOptRepoCipherType, repoIdx));
+
+            // Attempt to load the archive info file
+            InfoArchive *info = infoArchiveLoadFile(
+                storageRepoIdx(repoIdx), INFO_ARCHIVE_PATH_FILE_STR, result.repoData[repoIdx].cipherType,
+                cfgOptionIdxStrNull(cfgOptRepoCipherPass, repoIdx));
+
+            // Get archive id for the most recent version -- archive-push will only operate against the most recent version
+            String *archiveId = infoPgArchiveId(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
+            InfoPgData archiveInfo = infoPgData(infoArchivePg(info), infoPgDataCurrentId(infoArchivePg(info)));
+
+            // Ensure that stanza version and system identifier match pg_control when available or the other repos when pg_control
+            // is not available
+            if (pgPathSet || repoIdx > 0)
+            {
+                if (result.pgVersion != archiveInfo.version || result.pgSystemId != archiveInfo.systemId)
+                {
+                    THROW_FMT(
+                        ArchiveMismatchError,
+                        "%s version %s, system-id %" PRIu64 " do not match %s stanza version %s, system-id %" PRIu64
+                        "\nHINT: are you archiving to the correct stanza?",
+                        pgPathSet ? PG_NAME : strZ(strNewFmt("repo%u stanza", cfgOptionGroupIdxToKey(cfgOptGrpRepo, 0))),
+                        strZ(pgVersionToStr(result.pgVersion)), result.pgSystemId,
+                        strZ(strNewFmt("repo%u", cfgOptionGroupIdxToKey(cfgOptGrpRepo, repoIdx))),
+                        strZ(pgVersionToStr(archiveInfo.version)), archiveInfo.systemId);
+                }
+            }
+
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                result.pgVersion = archiveInfo.version;
+                result.pgSystemId = archiveInfo.systemId;
+                result.repoData[repoIdx].archiveId = strDup(archiveId);
+                result.repoData[repoIdx].cipherPass = strDup(infoArchiveCipherPass(info));
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
-        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(ARCHIVE_PUSH_CHECK_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
 /**********************************************************************************************************************************/
@@ -284,10 +298,14 @@ cmdArchivePush(void)
 
             // pg1-path is not optional for async mode
             if (!cfgOptionTest(cfgOptPgPath))
-                THROW(OptionRequiredError, "'" CFGCMD_ARCHIVE_PUSH "' command in async mode requires option '" CFGOPT_PG1_PATH "'");
+            {
+                THROW_FMT(
+                    OptionRequiredError, "'" CFGCMD_ARCHIVE_PUSH "' command in async mode requires option '%s'",
+                    cfgOptionName(cfgOptPgPath));
+            }
 
             // Loop and wait for the WAL segment to be pushed
-            Wait *wait = waitNew((TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
+            Wait *wait = waitNew(cfgOptionUInt64(cfgOptArchiveTimeout));
 
             do
             {
@@ -299,7 +317,9 @@ cmdArchivePush(void)
                 // forking the async process off more than once so track that as well.  Use an archive lock to prevent more than
                 // one async process being launched.
                 if (!pushed && !forked &&
-                    lockAcquire(cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgLockType(), 0, false))
+                    lockAcquire(
+                        cfgOptionStr(cfgOptLockPath), cfgOptionStr(cfgOptStanza), cfgOptionStr(cfgOptExecId), cfgLockType(), 0,
+                        false))
                 {
                     // The async process should not output on the console at all
                     KeyValue *optionReplace = kvNew();
@@ -335,8 +355,8 @@ cmdArchivePush(void)
             if (!pushed)
             {
                 THROW_FMT(
-                    ArchiveTimeoutError, "unable to push WAL file '%s' to the archive asynchronously after %lg second(s)",
-                    strZ(archiveFile), cfgOptionDbl(cfgOptArchiveTimeout));
+                    ArchiveTimeoutError, "unable to push WAL file '%s' to the archive asynchronously after %s second(s)",
+                    strZ(archiveFile), strZ(strNewDbl((double)cfgOptionInt64(cfgOptArchiveTimeout) / MSEC_PER_SEC)));
             }
 
             // Log success
@@ -344,14 +364,6 @@ cmdArchivePush(void)
         }
         else
         {
-            // Get the repo storage in case it is remote and encryption settings need to be pulled down
-            storageRepo();
-
-            // Get archive info
-            ArchivePushCheckResult archiveInfo = archivePushCheck(
-                cfgOptionTest(cfgOptPgPath), cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-                cfgOptionStrNull(cfgOptRepoCipherPass));
-
             // Check if the push queue has been exceeded
             if (cfgOptionTest(cfgOptArchivePushQueueMax) &&
                 archivePushDrop(strPath(walFile), archivePushReadyList(strPath(walFile))))
@@ -361,11 +373,13 @@ cmdArchivePush(void)
             // Else push the file
             else
             {
+                // Check archive info for each repo
+                ArchivePushCheckResult archiveInfo = archivePushCheck(cfgOptionTest(cfgOptPgPath));
+
                 // Push the file to the archive
                 String *warning = archivePushFile(
-                    walFile, archiveInfo.archiveId, archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
-                    cipherType(cfgOptionStr(cfgOptRepoCipherType)), archiveInfo.archiveCipherPass,
-                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel));
+                    walFile, archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
+                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel), archiveInfo.repoData);
 
                 // If a warning was returned then log it
                 if (warning != NULL)
@@ -387,13 +401,13 @@ typedef struct ArchivePushAsyncData
     const String *walPath;                                          // Path to pg_wal/pg_xlog
     const StringList *walFileList;                                  // List of wal files to process
     unsigned int walFileIdx;                                        // Current index in the list to be processed
-    CipherType cipherType;                                          // Cipher type
     CompressType compressType;                                      // Type of compression for WAL segments
     int compressLevel;                                              // Compression level for wal files
     ArchivePushCheckResult archiveInfo;                             // Archive info
 } ArchivePushAsyncData;
 
-static ProtocolParallelJob *archivePushAsyncCallback(void *data, unsigned int clientIdx)
+static ProtocolParallelJob *
+archivePushAsyncCallback(void *data, unsigned int clientIdx)
 {
     FUNCTION_TEST_BEGIN();
         FUNCTION_TEST_PARAM_P(VOID, data);
@@ -413,15 +427,20 @@ static ProtocolParallelJob *archivePushAsyncCallback(void *data, unsigned int cl
 
         ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_ARCHIVE_PUSH_STR);
         protocolCommandParamAdd(command, VARSTR(strNewFmt("%s/%s", strZ(jobData->walPath), strZ(walFile))));
-        protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.archiveId));
         protocolCommandParamAdd(command, VARUINT(jobData->archiveInfo.pgVersion));
         protocolCommandParamAdd(command, VARUINT64(jobData->archiveInfo.pgSystemId));
         protocolCommandParamAdd(command, VARSTR(walFile));
-        protocolCommandParamAdd(command, VARUINT(jobData->cipherType));
-        protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.archiveCipherPass));
         protocolCommandParamAdd(command, VARUINT(jobData->compressType));
         protocolCommandParamAdd(command, VARINT(jobData->compressLevel));
 
+        // Add data for each repo to push to
+        for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
+        {
+            protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.repoData[repoIdx].archiveId));
+            protocolCommandParamAdd(command, VARUINT(jobData->archiveInfo.repoData[repoIdx].cipherType));
+            protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.repoData[repoIdx].cipherPass));
+        }
+
         FUNCTION_TEST_RETURN(protocolParallelJobNew(VARSTR(walFile), command));
     }
 
@@ -462,7 +481,7 @@ cmdArchivePushAsync(void)
             jobData.walFileList = archivePushProcessList(jobData.walPath);
 
             // The archive-push:async command should not have been called unless there are WAL files to process
-            if (strLstSize(jobData.walFileList) == 0)
+            if (strLstEmpty(jobData.walFileList))
                 THROW(AssertError, "no WAL files to process");
 
             LOG_INFO_FMT(
@@ -485,22 +504,15 @@ cmdArchivePushAsync(void)
             // Else continue processing
             else
             {
-                // Get the repo storage in case it is remote and encryption settings need to be pulled down
-                storageRepo();
-
-                // Get cipher type
-                jobData.cipherType = cipherType(cfgOptionStr(cfgOptRepoCipherType));
-
-                // Get archive info
-                jobData.archiveInfo = archivePushCheck(
-                    true, cipherType(cfgOptionStr(cfgOptRepoCipherType)), cfgOptionStrNull(cfgOptRepoCipherPass));
+                // Check archive info for each repo
+                jobData.archiveInfo = archivePushCheck(true);
 
                 // Create the parallel executor
                 ProtocolParallel *parallelExec = protocolParallelNew(
-                    (TimeMSec)(cfgOptionDbl(cfgOptProtocolTimeout) * MSEC_PER_SEC) / 2, archivePushAsyncCallback, &jobData);
+                    cfgOptionUInt64(cfgOptProtocolTimeout) / 2, archivePushAsyncCallback, &jobData);
 
                 for (unsigned int processIdx = 1; processIdx <= cfgOptionUInt(cfgOptProcessMax); processIdx++)
-                    protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 1, processIdx));
+                    protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypeRepo, 0, processIdx));
 
                 // Process jobs
                 do
@@ -519,8 +531,17 @@ cmdArchivePushAsync(void)
                         // The job was successful
                         if (protocolParallelJobErrorCode(job) == 0)
                         {
+                            // If there was a warning then output it to the log
+                            const String *warning = varStr(protocolParallelJobResult(job));
+
+                            if (warning != NULL)
+                                LOG_WARN_PID(processId, strZ(warning));
+
+                            // Log success
                             LOG_DETAIL_PID_FMT(processId, "pushed WAL file '%s' to the archive", strZ(walFile));
-                            archiveAsyncStatusOkWrite(archiveModePush, walFile, varStr(protocolParallelJobResult(job)));
+
+                            // Write the status file
+                            archiveAsyncStatusOkWrite(archiveModePush, walFile, warning);
                         }
                         // Else the job errored
                         else
