@@ -101,7 +101,7 @@ backupLabelCreate(BackupType type, const String *backupLabelPrior, time_t timest
                 .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
             sortOrderDesc);
 
-        if (strLstSize(backupList) > 0)
+        if (!strLstEmpty(backupList))
             backupLabelLatest = strLstGet(backupList, 0);
 
         // Get the newest history
@@ -109,7 +109,7 @@ backupLabelCreate(BackupType type, const String *backupLabelPrior, time_t timest
             storageListP(storageRepo(), STRDEF(STORAGE_REPO_BACKUP "/" BACKUP_PATH_HISTORY), .expression = STRDEF("^2[0-9]{3}$")),
             sortOrderDesc);
 
-        if (strLstSize(historyYearList) > 0)
+        if (!strLstEmpty(historyYearList))
         {
             const StringList *historyList = strLstSort(
                 storageListP(
@@ -121,7 +121,7 @@ backupLabelCreate(BackupType type, const String *backupLabelPrior, time_t timest
                         strZ(compressTypeStr(compressTypeGz)))),
                 sortOrderDesc);
 
-            if (strLstSize(historyList) > 0)
+            if (!strLstEmpty(historyList))
             {
                 const String *historyLabelLatest = strLstGet(historyList, 0);
 
@@ -175,12 +175,12 @@ Get the postgres database and storage objects
 
 typedef struct BackupData
 {
-    unsigned int pgIdPrimary;                                       // Configuration id of the primary
+    unsigned int pgIdxPrimary;                                      // cfgOptGrpPg index of the primary
     Db *dbPrimary;                                                  // Database connection to the primary
     const Storage *storagePrimary;                                  // Storage object for the primary
     const String *hostPrimary;                                      // Host name of the primary
 
-    unsigned int pgIdStandby;                                       // Configuration id of the standby
+    unsigned int pgIdxStandby;                                      // cfgOptGrpPg index of the standby
     Db *dbStandby;                                                  // Database connection to the standby
     const Storage *storageStandby;                                  // Storage object for the standby
     const String *hostStandby;                                      // Host name of the standby
@@ -200,7 +200,7 @@ backupInit(const InfoBackup *infoBackup)
 
     // Initialize for offline backup
     BackupData *result = memNew(sizeof(BackupData));
-    *result = (BackupData){.pgIdPrimary = 1};
+    *result = (BackupData){0};
 
     // Check that the PostgreSQL version supports backup from standby. The check is done using the stanza info because pg_control
     // cannot be loaded until a primary is found -- which will also lead to an error if the version does not support standby. If the
@@ -228,23 +228,23 @@ backupInit(const InfoBackup *infoBackup)
         bool backupStandby = cfgOptionBool(cfgOptBackupStandby);
         DbGetResult dbInfo = dbGet(!backupStandby, true, backupStandby);
 
-        result->pgIdPrimary = dbInfo.primaryId;
+        result->pgIdxPrimary = dbInfo.primaryIdx;
         result->dbPrimary = dbInfo.primary;
 
         if (backupStandby)
         {
-            ASSERT(dbInfo.standbyId != 0);
+            ASSERT(dbInfo.standby != NULL);
 
-            result->pgIdStandby = dbInfo.standbyId;
+            result->pgIdxStandby = dbInfo.standbyIdx;
             result->dbStandby = dbInfo.standby;
-            result->storageStandby = storagePgId(result->pgIdStandby);
-            result->hostStandby = cfgOptionStrNull(cfgOptPgHost + result->pgIdStandby - 1);
+            result->storageStandby = storagePgIdx(result->pgIdxStandby);
+            result->hostStandby = cfgOptionIdxStrNull(cfgOptPgHost, result->pgIdxStandby);
         }
     }
 
     // Add primary info
-    result->storagePrimary = storagePgId(result->pgIdPrimary);
-    result->hostPrimary = cfgOptionStrNull(cfgOptPgHost + result->pgIdPrimary - 1);
+    result->storagePrimary = storagePgIdx(result->pgIdxPrimary);
+    result->hostPrimary = cfgOptionIdxStrNull(cfgOptPgHost, result->pgIdxPrimary);
 
     // Get pg_control info from the primary
     PgControl pgControl = pgControlFromFile(result->storagePrimary);
@@ -324,11 +324,25 @@ backupTime(BackupData *backupData, bool waitRemainder)
         // Sleep the remainder of the second when requested (this is so copyStart is not subject to one second resolution issues)
         if (waitRemainder)
         {
-            sleepMSec(MSEC_PER_SEC - (timeMSec % MSEC_PER_SEC));
+            unsigned int retry = 0;
 
-            // Check time again to be sure we slept long enough
-            if (result >= (time_t)(dbTimeMSec(backupData->dbPrimary) / MSEC_PER_SEC))
-                THROW(AssertError, "invalid sleep for online backup time with wait remainder");
+            // Just to be safe we'll loop until PostgreSQL reports that we have slept long enough
+            do
+            {
+                // Error if the clock has not advanced after several attempts
+                if (retry == 3)
+                    THROW_FMT(KernelError, PG_NAME " clock has not advanced to the next second after %u tries", retry);
+
+                // Sleep remainder of current second
+                sleepMSec(((TimeMSec)(result + 1) * MSEC_PER_SEC) - timeMSec);
+
+                // Check time again to be sure we slept long enough
+                timeMSec = dbTimeMSec(backupData->dbPrimary);
+
+                // Increment retry to prevent an infinite loop
+                retry++;
+            }
+            while ((time_t)(timeMSec / MSEC_PER_SEC) <= result);
         }
     }
 
@@ -633,19 +647,15 @@ void backupResumeCallback(void *data, const StorageInfo *info)
         // The link will be recreated during the backup if needed.
         // -------------------------------------------------------------------------------------------------------------------------
         case storageTypeLink:
-        {
             storageRemoveP(storageRepoWrite(), backupPath);
             break;
-        }
 
         // Remove special files
         // -------------------------------------------------------------------------------------------------------------------------
         case storageTypeSpecial:
-        {
             LOG_WARN_FMT("remove special file '%s' from resumed backup", strZ(storagePathP(storageRepo(), backupPath)));
             storageRemoveP(storageRepoWrite(), backupPath);
             break;
-        }
     }
 
     FUNCTION_TEST_RETURN_VOID();
@@ -673,70 +683,77 @@ backupResumeFind(const Manifest *manifest, const String *cipherPassBackup)
                 .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
             sortOrderDesc);
 
-        if (strLstSize(backupList) > 0)
+        if (!strLstEmpty(backupList))
         {
             const String *backupLabel = strLstGet(backupList, 0);
             const String *manifestFile = strNewFmt(STORAGE_REPO_BACKUP "/%s/" BACKUP_MANIFEST_FILE, strZ(backupLabel));
 
-            // Resumable backups have a copy of the manifest but no main
-            if (storageExistsP(storageRepo(), strNewFmt("%s" INFO_COPY_EXT, strZ(manifestFile))) &&
-                !storageExistsP(storageRepo(), manifestFile))
+            // Resumable backups do not have backup.manifest
+            if (!storageExistsP(storageRepo(), manifestFile))
             {
                 bool usable = false;
-                const String *reason = STRDEF("resume is disabled");
+                const String *reason = STRDEF("partially deleted by prior resume or invalid");
                 Manifest *manifestResume = NULL;
 
-                // Attempt to read the manifest file in the resumable backup to see if it can be used.  If any error at all occurs
-                // then the backup will be considered unusable and a resume will not be attempted.
-                if (cfgOptionBool(cfgOptResume))
+                // Resumable backups must have backup.manifest.copy
+                if (storageExistsP(storageRepo(), strNewFmt("%s" INFO_COPY_EXT, strZ(manifestFile))))
                 {
-                    reason = strNewFmt("unable to read %s" INFO_COPY_EXT, strZ(manifestFile));
+                    reason = STRDEF("resume is disabled");
 
-                    TRY_BEGIN()
+                    // Attempt to read the manifest file in the resumable backup to see if it can be used. If any error at all
+                    // occurs then the backup will be considered unusable and a resume will not be attempted.
+                    if (cfgOptionBool(cfgOptResume))
                     {
-                        manifestResume = manifestLoadFile(
-                            storageRepo(), manifestFile, cipherType(cfgOptionStr(cfgOptRepoCipherType)), cipherPassBackup);
-                        const ManifestData *manifestResumeData = manifestData(manifestResume);
+                        reason = strNewFmt("unable to read %s" INFO_COPY_EXT, strZ(manifestFile));
 
-                        // Check pgBackRest version. This allows the resume implementation to be changed with each version of
-                        // pgBackRest at the expense of users losing a resumable back after an upgrade, which seems worth the cost.
-                        if (!strEq(manifestResumeData->backrestVersion, manifestData(manifest)->backrestVersion))
+                        TRY_BEGIN()
                         {
-                            reason = strNewFmt(
-                                "new " PROJECT_NAME " version '%s' does not match resumable " PROJECT_NAME " version '%s'",
-                                strZ(manifestData(manifest)->backrestVersion), strZ(manifestResumeData->backrestVersion));
+                            manifestResume = manifestLoadFile(
+                                storageRepo(), manifestFile, cipherType(cfgOptionStr(cfgOptRepoCipherType)), cipherPassBackup);
+                            const ManifestData *manifestResumeData = manifestData(manifestResume);
+
+                            // Check pgBackRest version. This allows the resume implementation to be changed with each version of
+                            // pgBackRest at the expense of users losing a resumable back after an upgrade, which seems worth the
+                            // cost.
+                            if (!strEq(manifestResumeData->backrestVersion, manifestData(manifest)->backrestVersion))
+                            {
+                                reason = strNewFmt(
+                                    "new " PROJECT_NAME " version '%s' does not match resumable " PROJECT_NAME " version '%s'",
+                                    strZ(manifestData(manifest)->backrestVersion), strZ(manifestResumeData->backrestVersion));
+                            }
+                            // Check backup type because new backup label must be the same type as resume backup label
+                            else if (manifestResumeData->backupType != backupType(cfgOptionStr(cfgOptType)))
+                            {
+                                reason = strNewFmt(
+                                    "new backup type '%s' does not match resumable backup type '%s'",
+                                    strZ(cfgOptionStr(cfgOptType)), strZ(backupTypeStr(manifestResumeData->backupType)));
+                            }
+                            // Check prior backup label ??? Do we really care about the prior backup label?
+                            else if (!strEq(manifestResumeData->backupLabelPrior, manifestData(manifest)->backupLabelPrior))
+                            {
+                                reason = strNewFmt(
+                                    "new prior backup label '%s' does not match resumable prior backup label '%s'",
+                                    manifestResumeData->backupLabelPrior ? strZ(manifestResumeData->backupLabelPrior) : "<undef>",
+                                    manifestData(manifest)->backupLabelPrior ?
+                                        strZ(manifestData(manifest)->backupLabelPrior) : "<undef>");
+                            }
+                            // Check compression. Compression can't be changed between backups so resume won't work either.
+                            else if (
+                                manifestResumeData->backupOptionCompressType != compressTypeEnum(cfgOptionStr(cfgOptCompressType)))
+                            {
+                                reason = strNewFmt(
+                                    "new compression '%s' does not match resumable compression '%s'",
+                                    strZ(compressTypeStr(compressTypeEnum(cfgOptionStr(cfgOptCompressType)))),
+                                    strZ(compressTypeStr(manifestResumeData->backupOptionCompressType)));
+                            }
+                            else
+                                usable = true;
                         }
-                        // Check backup type because new backup label must be the same type as resume backup label
-                        else if (manifestResumeData->backupType != backupType(cfgOptionStr(cfgOptType)))
+                        CATCH_ANY()
                         {
-                            reason = strNewFmt(
-                                "new backup type '%s' does not match resumable backup type '%s'", strZ(cfgOptionStr(cfgOptType)),
-                                strZ(backupTypeStr(manifestResumeData->backupType)));
                         }
-                        // Check prior backup label ??? Do we really care about the prior backup label?
-                        else if (!strEq(manifestResumeData->backupLabelPrior, manifestData(manifest)->backupLabelPrior))
-                        {
-                            reason = strNewFmt(
-                                "new prior backup label '%s' does not match resumable prior backup label '%s'",
-                                manifestResumeData->backupLabelPrior ? strZ(manifestResumeData->backupLabelPrior) : "<undef>",
-                                manifestData(manifest)->backupLabelPrior ?
-                                    strZ(manifestData(manifest)->backupLabelPrior) : "<undef>");
-                        }
-                        // Check compression. Compression can't be changed between backups so resume won't work either.
-                        else if (manifestResumeData->backupOptionCompressType != compressTypeEnum(cfgOptionStr(cfgOptCompressType)))
-                        {
-                            reason = strNewFmt(
-                                "new compression '%s' does not match resumable compression '%s'",
-                                strZ(compressTypeStr(compressTypeEnum(cfgOptionStr(cfgOptCompressType)))),
-                                strZ(compressTypeStr(manifestResumeData->backupOptionCompressType)));
-                        }
-                        else
-                            usable = true;
+                        TRY_END();
                     }
-                    CATCH_ANY()
-                    {
-                    }
-                    TRY_END();
                 }
 
                 // If the backup is usable then return the manifest
@@ -822,11 +839,6 @@ typedef struct BackupStartResult
     VariantList *tablespaceList;
 } BackupStartResult;
 
-#define FUNCTION_LOG_BACKUP_START_RESULT_TYPE                                                                                      \
-    BackupStartResult
-#define FUNCTION_LOG_BACKUP_START_RESULT_FORMAT(value, buffer, bufferSize)                                                         \
-    objToLog(&value, "BackupStartResult", buffer, bufferSize)
-
 static BackupStartResult
 backupStart(BackupData *backupData)
 {
@@ -864,7 +876,7 @@ backupStart(BackupData *backupData)
         else
         {
             // Check database configuration
-            checkDbConfig(backupData->version, backupData->pgIdPrimary, backupData->dbPrimary, false);
+            checkDbConfig(backupData->version, backupData->pgIdxPrimary, backupData->dbPrimary, false);
 
             // Start backup
             LOG_INFO_FMT(
@@ -890,20 +902,20 @@ backupStart(BackupData *backupData)
             if (cfgOptionBool(cfgOptBackupStandby))
             {
                 LOG_INFO_FMT("wait for replay on the standby to reach %s", strZ(result.lsn));
-                dbReplayWait(backupData->dbStandby, result.lsn, (TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
+                dbReplayWait(backupData->dbStandby, result.lsn, cfgOptionUInt64(cfgOptArchiveTimeout));
                 LOG_INFO_FMT("replay on the standby reached %s", strZ(result.lsn));
 
                 // The standby db object won't be used anymore so free it
                 dbFree(backupData->dbStandby);
 
                 // The standby protocol connection won't be used anymore so free it
-                protocolRemoteFree(backupData->pgIdStandby);
+                protocolRemoteFree(backupData->pgIdxStandby);
             }
         }
     }
     MEM_CONTEXT_TEMP_END();
 
-    FUNCTION_LOG_RETURN(BACKUP_START_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
 /***********************************************************************************************************************************
@@ -997,11 +1009,6 @@ typedef struct BackupStopResult
     time_t timestamp;
 } BackupStopResult;
 
-#define FUNCTION_LOG_BACKUP_STOP_RESULT_TYPE                                                                                       \
-    BackupStopResult
-#define FUNCTION_LOG_BACKUP_STOP_RESULT_FORMAT(value, buffer, bufferSize)                                                          \
-    objToLog(&value, "BackupStopResult", buffer, bufferSize)
-
 static BackupStopResult
 backupStop(BackupData *backupData, Manifest *manifest)
 {
@@ -1042,7 +1049,7 @@ backupStop(BackupData *backupData, Manifest *manifest)
     else
         result.timestamp = backupTime(backupData, false);
 
-    FUNCTION_LOG_RETURN(BACKUP_STOP_RESULT, result);
+    FUNCTION_LOG_RETURN_STRUCT(result);
 }
 
 /***********************************************************************************************************************************
@@ -1159,7 +1166,7 @@ backupJobResult(
                         {
                             // Format the page checksum errors
                             checksumPageErrorList = varVarLst(kvGet(checksumPageResult, VARSTRDEF("error")));
-                            ASSERT(varLstSize(checksumPageErrorList) > 0);
+                            ASSERT(!varLstEmpty(checksumPageErrorList));
 
                             String *error = strNew("");
                             unsigned int errorTotalMin = 0;
@@ -1465,7 +1472,7 @@ static ProtocolParallelJob *backupJobCallback(void *data, unsigned int clientIdx
         {
             List *queue = *(List **)lstGet(jobData->queueList, (unsigned int)queueIdx + queueOffset);
 
-            if (lstSize(queue) > 0)
+            if (!lstEmpty(queue))
             {
                 const ManifestFile *file = *(ManifestFile **)lstGet(queue, 0);
 
@@ -1585,18 +1592,18 @@ backupProcess(BackupData *backupData, Manifest *manifest, const String *lsnStart
 
         // Create the parallel executor
         ProtocolParallel *parallelExec = protocolParallelNew(
-            (TimeMSec)(cfgOptionDbl(cfgOptProtocolTimeout) * MSEC_PER_SEC) / 2, backupJobCallback, &jobData);
+            cfgOptionUInt64(cfgOptProtocolTimeout) / 2, backupJobCallback, &jobData);
 
         // First client is always on the primary
-        protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypePg, backupData->pgIdPrimary, 1));
+        protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypePg, backupData->pgIdxPrimary, 1));
 
         // Create the rest of the clients on the primary or standby depending on the value of backup-standby.  Note that standby
         // backups don't count the primary client in process-max.
         unsigned int processMax = cfgOptionUInt(cfgOptProcessMax) + (backupStandby ? 1 : 0);
-        unsigned int pgId = backupStandby ? backupData->pgIdStandby : backupData->pgIdPrimary;
+        unsigned int pgIdx = backupStandby ? backupData->pgIdxStandby : backupData->pgIdxPrimary;
 
         for (unsigned int processIdx = 2; processIdx <= processMax; processIdx++)
-            protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypePg, pgId, processIdx));
+            protocolParallelClientAdd(parallelExec, protocolLocalGet(protocolStorageTypePg, pgIdx, processIdx));
 
         // Maintain a list of files that need to be removed from the manifest when the backup is complete
         StringList *fileRemove = strLstNew();
@@ -1625,7 +1632,7 @@ backupProcess(BackupData *backupData, Manifest *manifest, const String *lsnStart
                         manifest,
                         backupStandby && protocolParallelJobProcessId(job) > 1 ? backupData->hostStandby : backupData->hostPrimary,
                         storagePathP(
-                            protocolParallelJobProcessId(job) > 1 ? storagePgId(pgId) : backupData->storagePrimary,
+                            protocolParallelJobProcessId(job) > 1 ? storagePgIdx(pgIdx) : backupData->storagePrimary,
                             manifestPathPg(manifestFileFind(manifest, varStr(protocolParallelJobKey(job)))->name)),
                         fileRemove, job, sizeTotal, sizeCopied);
                 }
@@ -1650,7 +1657,7 @@ backupProcess(BackupData *backupData, Manifest *manifest, const String *lsnStart
 #ifdef DEBUG
         // Ensure that all processing queues are empty
         for (unsigned int queueIdx = 0; queueIdx < lstSize(jobData.queueList); queueIdx++)
-            ASSERT(lstSize(*(List **)lstGet(jobData.queueList, queueIdx)) == 0);
+            ASSERT(lstEmpty(*(List **)lstGet(jobData.queueList, queueIdx)));
 #endif
 
         // Remove files from the manifest that were removed during the backup.  This must happen after processing to avoid
@@ -1760,7 +1767,7 @@ backupArchiveCheckCopy(Manifest *manifest, unsigned int walSegmentSize, const St
 
                 // Find the actual wal segment file in the archive
                 const String *archiveFile = walSegmentFind(
-                    storageRepo(), archiveId, walSegment,  (TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
+                    storageRepo(), archiveId, walSegment,  cfgOptionUInt64(cfgOptArchiveTimeout));
 
                 if (cfgOptionBool(cfgOptArchiveCopy))
                 {
@@ -1997,7 +2004,7 @@ cmdBackup(void)
         // The primary protocol connection won't be used anymore so free it. This needs to happen after backupArchiveCheckCopy() so
         // the backup lock is held on the remote which allows conditional archiving based on the backup lock. Any further access to
         // the primary storage object may result in an error (likely eof).
-        protocolRemoteFree(backupData->pgIdPrimary);
+        protocolRemoteFree(backupData->pgIdxPrimary);
 
         // Complete the backup
         LOG_INFO_FMT("new backup label = %s", strZ(manifestData(manifest)->backupLabel));
