@@ -125,7 +125,7 @@ testRun(void)
         StringList *argList = strLstNew();
         strLstAdd(argList, strNewFmt("--spool-path=%s", testPath()));
         strLstAddZ(argList, "--stanza=db");
-        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/path/to/pg");
+        hrnCfgArgRawZ(argList, cfgOptPgPath, "/path/to/pg");
         strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
         harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argList);
 
@@ -226,7 +226,7 @@ testRun(void)
         // Load configuration to set repo-path and stanza
         StringList *argList = strLstNew();
         strLstAddZ(argList, "--stanza=db");
-        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/path/to/pg");
+        hrnCfgArgRawZ(argList, cfgOptPgPath, "/path/to/pg");
         strLstAdd(argList, strNewFmt("--repo-path=%s", testPath()));
         strLstAddZ(argList, "archive-get");
         harnessCfgLoad(cfgCmdArchiveGet, argList);
@@ -313,25 +313,25 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("walSegmentRange()"))
     {
-        TEST_RESULT_STR_Z(
-            strLstJoin(walSegmentRange(strNew("000000010000000100000000"), 16 * 1024 * 1024, PG_VERSION_92, 1), "|"),
-            "000000010000000100000000", "get single");
-        TEST_RESULT_STR_Z(
-            strLstJoin(walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_92, 4), "|"),
-            "0000000100000001000000FD|0000000100000001000000FE|000000010000000200000000|000000010000000200000001",
+        TEST_RESULT_STRLST_Z(
+            walSegmentRange(strNew("000000010000000100000000"), 16 * 1024 * 1024, PG_VERSION_92, 1), "000000010000000100000000\n",
+            "get single");
+        TEST_RESULT_STRLST_Z(
+            walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_92, 4),
+            "0000000100000001000000FD\n0000000100000001000000FE\n000000010000000200000000\n000000010000000200000001\n",
             "get range < 9.3");
-        TEST_RESULT_STR_Z(
-            strLstJoin(walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_93, 4), "|"),
-            "0000000100000001000000FD|0000000100000001000000FE|0000000100000001000000FF|000000010000000200000000",
+        TEST_RESULT_STRLST_Z(
+            walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_93, 4),
+            "0000000100000001000000FD\n0000000100000001000000FE\n0000000100000001000000FF\n000000010000000200000000\n",
             "get range >= 9.3");
-        TEST_RESULT_STR_Z(
-            strLstJoin(walSegmentRange(strNew("000000080000000A00000000"), 1024 * 1024 * 1024, PG_VERSION_11, 8), "|"),
-            "000000080000000A00000000|000000080000000A00000001|000000080000000A00000002|000000080000000A00000003|"
-            "000000080000000B00000000|000000080000000B00000001|000000080000000B00000002|000000080000000B00000003",
+        TEST_RESULT_STRLST_Z(
+            walSegmentRange(strNew("000000080000000A00000000"), 1024 * 1024 * 1024, PG_VERSION_11, 8),
+            "000000080000000A00000000\n000000080000000A00000001\n000000080000000A00000002\n000000080000000A00000003\n"
+            "000000080000000B00000000\n000000080000000B00000001\n000000080000000B00000002\n000000080000000B00000003\n",
             "get range >= 11/1GB");
-        TEST_RESULT_STR_Z(
-            strLstJoin(walSegmentRange(strNew("000000070000000700000FFE"), 1024 * 1024, PG_VERSION_11, 4), "|"),
-            "000000070000000700000FFE|000000070000000700000FFF|000000070000000800000000|000000070000000800000001",
+        TEST_RESULT_STRLST_Z(
+            walSegmentRange(strNew("000000070000000700000FFE"), 1024 * 1024, PG_VERSION_11, 4),
+            "000000070000000700000FFE\n000000070000000700000FFF\n000000070000000800000000\n000000070000000800000001\n",
             "get range >= 11/1MB");
     }
 
@@ -347,10 +347,10 @@ testRun(void)
         strLstAddZ(list, "11-10");
         strLstAddZ(list, "9.6-1");
 
-        TEST_RESULT_STR_Z(strLstJoin(strLstSort(list, sortOrderAsc), ", "), "9.6-1, 10-4, 11-10", "sort ascending");
+        TEST_RESULT_STRLST_Z(strLstSort(list, sortOrderAsc), "9.6-1\n10-4\n11-10\n", "sort ascending");
 
         strLstAddZ(list, "9.4-2");
-        TEST_RESULT_STR_Z(strLstJoin(strLstSort(list, sortOrderDesc), ", "), "11-10, 10-4, 9.4-2, 9.6-1", "sort descending");
+        TEST_RESULT_STRLST_Z(strLstSort(list, sortOrderDesc), "11-10\n10-4\n9.4-2\n9.6-1\n", "sort descending");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
