@@ -52,43 +52,6 @@ testRun(void)
         TEST_RESULT_BOOL(varEq(BOOL_FALSE_VAR, BOOL_TRUE_VAR), false, "bool, bool not eq");
     }
 
-    // *****************************************************************************************************************************
-    if (testBegin("double"))
-    {
-        // Ensure type sizes are as expected
-        TEST_RESULT_UINT(sizeof(VariantDoubleConst), TEST_64BIT() ? 16 : 12, "check VariantDoubleConst size");
-        TEST_RESULT_UINT(sizeof(VariantDouble), TEST_64BIT() ? 24 : 16, "check VariantDouble size");
-
-        Variant *var = varNewDbl(44.44);
-        TEST_RESULT_DOUBLE(varDbl(var), 44.44, "double variant");
-        varFree(var);
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_ERROR(varDbl(varNewStrZ("string")), AssertError, "assertion 'this->type == varTypeDouble' failed");
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_DOUBLE(varDblForce(VARDBL(4.567)), 4.567, "force double to double");
-        TEST_RESULT_DOUBLE(varDblForce(varNewBool(false)), 0, "force bool to double");
-        TEST_RESULT_DOUBLE(varDblForce(VARINT(123)), 123, "force int to double");
-        TEST_RESULT_DOUBLE(varDblForce(VARINT64(999999999999)), 999999999999, "force int64 to double");
-        TEST_RESULT_DOUBLE(varDblForce(VARUINT64(9223372036854775807U)), 9223372036854775807.0, "force uint64 to double");
-        TEST_RESULT_DOUBLE(varDblForce(VARUINT(992)), 992, "force uint to double");
-        TEST_RESULT_DOUBLE(varDblForce(VARSTRDEF("879.01")), 879.01, "force String to double");
-        TEST_RESULT_DOUBLE(varDblForce(VARSTRDEF("0")), 0, "force String to double");
-        TEST_RESULT_DOUBLE(
-            varDblForce(VARUINT64(UINT64_MAX)), 18446744073709551616.0, "force max uint64 to double (it will be rounded)");
-
-        TEST_ERROR(varDblForce(VARSTRDEF("AAA")), FormatError, "unable to convert string 'AAA' to double");
-        TEST_ERROR(varDblForce(varNewVarLst(varLstNew())), AssertError, "unable to force VariantList to double");
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_DOUBLE(varDbl(varDup(VARDBL(3.1415))), 3.1415, "dup double");
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_BOOL(varEq(VARDBL(1.234), VARDBL(1.234)), true, "double, double eq");
-        TEST_RESULT_BOOL(varEq(VARDBL(4.321), VARDBL(1.234)), false, "double, double not eq");
-    }
-
     // *****************************************************************************************************************************
     if (testBegin("int"))
     {
@@ -178,16 +141,16 @@ testRun(void)
 
         // -------------------------------------------------------------------------------------------------------------------------
         Variant *unsignedint = varNewUInt(787);
-        TEST_RESULT_DOUBLE(varUInt(unsignedint), 787, "uint variant");
-        TEST_RESULT_DOUBLE(varUIntForce(unsignedint), 787, "force uint to uint");
+        TEST_RESULT_UINT(varUInt(unsignedint), 787, "uint variant");
+        TEST_RESULT_UINT(varUIntForce(unsignedint), 787, "force uint to uint");
         varFree(unsignedint);
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_DOUBLE(varUIntForce(varNewBool(true)), 1, "force bool to uint");
-        TEST_RESULT_DOUBLE(varUIntForce(VARINT(2147483647)), 2147483647, "force int to uint");
-        TEST_RESULT_DOUBLE(varUIntForce(VARINT64(2147483647)), 2147483647, "force int64 to uint");
-        TEST_RESULT_DOUBLE(varUIntForce(varNewStrZ("4294967295")), 4294967295, "force str to uint");
-        TEST_RESULT_DOUBLE(varUIntForce(VARUINT64(4294967295U)), 4294967295U, "force uint64 to uint");
+        TEST_RESULT_UINT(varUIntForce(varNewBool(true)), 1, "force bool to uint");
+        TEST_RESULT_UINT(varUIntForce(VARINT(2147483647)), 2147483647, "force int to uint");
+        TEST_RESULT_UINT(varUIntForce(VARINT64(2147483647)), 2147483647, "force int64 to uint");
+        TEST_RESULT_UINT(varUIntForce(varNewStrZ("4294967295")), 4294967295, "force str to uint");
+        TEST_RESULT_UINT(varUIntForce(VARUINT64(4294967295U)), 4294967295U, "force uint64 to uint");
 
         TEST_ERROR(
             varUIntForce(varNewStrZ("4294967296")), FormatError,
@@ -203,7 +166,7 @@ testRun(void)
         TEST_ERROR(varUInt(varNewStrZ("string")), AssertError, "assertion 'this->type == varTypeUInt' failed");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_DOUBLE(varUInt(varDup(VARUINT(88976))), 88976, "dup uint");
+        TEST_RESULT_UINT(varUInt(varDup(VARUINT(88976))), 88976, "dup uint");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_BOOL(varEq(VARUINT(9999), VARUINT(9999)), true, "uint, uint eq");
@@ -294,14 +257,14 @@ testRun(void)
         TEST_RESULT_UINT(sizeof(VariantString), TEST_64BIT() ? 24 : 12, "check VariantString size");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_PTR(strPtr(varStr(varNewStr(NULL))), NULL, "new null str");
+        TEST_RESULT_STR(varStr(varNewStr(NULL)), NULL, "new null str");
 
         // -------------------------------------------------------------------------------------------------------------------------
         Variant *string = varNewStr(strNew("test-str"));
         TEST_RESULT_STR_Z(varStr(string), "test-str", "string pointer");
         varFree(string);
 
-        TEST_RESULT_PTR(varStr(NULL), NULL, "get null string variant");
+        TEST_RESULT_STR(varStr(NULL), NULL, "get null string variant");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ERROR(varStr(varNewBool(true)), AssertError, "assertion 'this->type == varTypeString' failed");
@@ -324,7 +287,6 @@ testRun(void)
         TEST_RESULT_STR_Z(varStrForce(VARSTRDEF("teststring")), "teststring", "force string to string");
         TEST_RESULT_STR_Z(varStrForce(VARINT(999)), "999", "force int to string");
         TEST_RESULT_STR_Z(varStrForce(VARINT64(9223372036854775807L)), "9223372036854775807", "force int64 to string");
-        TEST_RESULT_STR_Z(varStrForce(VARDBL((double)999999999.123456)), "999999999.123456", "force double to string");
         TEST_RESULT_STR_Z(varStrForce(varNewBool(true)), "true", "force bool to string");
         TEST_RESULT_STR_Z(varStrForce(varNewBool(false)), "false", "force bool to string");
         TEST_RESULT_STR_Z(varStrForce(VARUINT64(18446744073709551615U)), "18446744073709551615", "force uint64 to string");
@@ -338,8 +300,8 @@ testRun(void)
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_STR_Z(varStr(VARSTRDEF("test-z-str")), "test-z-str", "new zero-terminated string");
-        TEST_RESULT_PTR(strPtr(varStr(VARSTR(NULL))), NULL, "new null strz");
-        TEST_RESULT_PTR(strPtr(varStr(varNewStrZ(NULL))), NULL, "new null strz");
+        TEST_RESULT_STR(varStr(VARSTR(NULL)), NULL, "new null strz");
+        TEST_RESULT_STR(varStr(varNewStrZ(NULL)), NULL, "new null strz");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_STR_Z(varStr(varDup(VARSTRDEF("yabba-dabba-doo"))), "yabba-dabba-doo", "dup string");
@@ -366,12 +328,14 @@ testRun(void)
         TEST_ASSIGN(listVar, varNewVarLst(varLstNew()), "new empty");
 
         TEST_RESULT_INT(varLstSize(varVarLst(listVar)), 0, "    empty size");
+        TEST_RESULT_BOOL(varLstEmpty(varVarLst(listVar)), true, "    empty");
         TEST_RESULT_PTR(varVarLst(NULL), NULL, "get null var list");
 
         TEST_RESULT_PTR(varLstAdd(varVarLst(listVar), varNewBool(true)), varVarLst(listVar), "    add bool");
         TEST_RESULT_PTR(varLstAdd(varVarLst(listVar), varNewInt(55)), varVarLst(listVar), "    add int");
 
         TEST_RESULT_INT(varLstSize(varVarLst(listVar)), 2, "    size with items");
+        TEST_RESULT_BOOL(varLstEmpty(varVarLst(listVar)), false, "    not empty");
 
         TEST_RESULT_BOOL(varBool(varLstGet(varVarLst(listVar), 0)), true, "    get bool");
         TEST_RESULT_INT(varInt(varLstGet(varVarLst(listVar), 1)), 55, "    get int");
@@ -436,7 +400,7 @@ testRun(void)
         varLstAdd(list, varNewStrZ("string1"));
         varLstAdd(list, varNewStrZ("string2"));
 
-        TEST_RESULT_STR_Z(strLstJoin(strLstNewVarLst(varLstDup(list)), ", "), "string1, string2", "duplicate variant list");
+        TEST_RESULT_STRLST_Z(strLstNewVarLst(varLstDup(list)), "string1\nstring2\n", "duplicate variant list");
 
         TEST_RESULT_PTR(varLstDup(NULL), NULL, "duplicate null list");
     }
@@ -449,8 +413,7 @@ testRun(void)
         strLstAdd(listStr, strNew("string1"));
         strLstAdd(listStr, strNew("string2"));
 
-        TEST_RESULT_STR_Z(
-            strLstJoin(strLstNewVarLst(varLstNewStrLst(listStr)), ", "), "string1, string2", "variant list from string list");
+        TEST_RESULT_STRLST_Z(strLstNewVarLst(varLstNewStrLst(listStr)), "string1\nstring2\n", "variant list from string list");
 
         TEST_RESULT_PTR(varLstNewStrLst(NULL), NULL, "variant list from null string list");
     }
