@@ -167,7 +167,9 @@ testRun(void)
 
                 driver.interface.infoList = storageTestPerfInfoList;
 
-                storageHelper.storageRepo = storageNew(STRDEF("TEST"), STRDEF("/"), 0, 0, false, NULL, &driver, driver.interface);
+                storageHelper.storageRepo = memNew(sizeof(Storage *));
+                storageHelper.storageRepo[0] = storageNew(
+                    STRDEF("TEST"), STRDEF("/"), 0, 0, false, NULL, &driver, driver.interface);
 
                 // Setup handler for remote storage protocol
                 IoRead *read = ioFdReadNew(strNew("storage server read"), HARNESS_FORK_CHILD_READ(), 60000);
@@ -235,7 +237,7 @@ testRun(void)
         ASSERT(bufUsed(block) == 1024 * 1024);
 
         // Build the input buffer
-        Buffer *input = bufNew(blockTotal * bufSize(block));
+        Buffer *input = bufNew((size_t)blockTotal * bufSize(block));
 
         for (unsigned int blockIdx = 0; blockIdx < blockTotal; blockIdx++)
             memcpy(bufPtr(input) + (blockIdx * bufSize(block)), bufPtr(block), bufSize(block));
@@ -244,7 +246,7 @@ testRun(void)
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE_FMT(
-            "%u iteration(s) of %" PRIu64 "MiB with %" PRIu64 "MB/s input, %" PRIu64 "MB/s output", iteration,
+            "%u iteration(s) of %zuMiB with %" PRIu64 "MB/s input, %" PRIu64 "MB/s output", iteration,
             bufUsed(input) / bufUsed(block), rateIn, rateOut);
 
         #define BENCHMARK_BEGIN()                                                                                                  \
@@ -287,7 +289,10 @@ testRun(void)
         uint64_t sha1Total = 1;
         uint64_t sha256Total = 1;
         uint64_t gzip6Total = 1;
+
+#ifdef HAVE_LIBLZ4
         uint64_t lz41Total = 1;
+#endif // HAVE_LIBLZ4
 
         for (unsigned int idx = 0; idx < iteration; idx++)
         {
@@ -346,6 +351,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_END();
 
             // -------------------------------------------------------------------------------------------------------------------------
+#ifdef HAVE_LIBLZ4
             TEST_LOG_FMT("lz4 -1 iteration %u", idx + 1);
 
             MEM_CONTEXT_TEMP_BEGIN()
@@ -355,6 +361,7 @@ testRun(void)
                 BENCHMARK_END(lz41Total);
             }
             MEM_CONTEXT_TEMP_END();
+#endif // HAVE_LIBLZ4
         }
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -370,7 +377,10 @@ testRun(void)
         TEST_RESULT("sha1", sha1Total);
         TEST_RESULT("sha256", sha256Total);
         TEST_RESULT("gzip -6", gzip6Total);
+
+#ifdef HAVE_LIBLZ4
         TEST_RESULT("lz4 -1", lz41Total);
+#endif // HAVE_LIBLZ4
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
